@@ -1,16 +1,30 @@
 #' Posteriors Sampling Diagnostic
 #'
-#' Extract diagnostic metrics (Effective Sample Size (\code{ESS}), \code{Rhat} and Monte Carlo Standard Error \code{MCSE}).
+#' Extract diagnostic metrics (Effective Sample Size (`ESS`), `Rhat` and Monte
+#' Carlo Standard Error `MCSE`).
 #'
-#' @param posteriors A stanreg or brms model.
-#' @param diagnostic Diagnostic metrics to compute.  Character (vector) or list with one or more of these options: \code{"ESS"}, \code{"Rhat"}, \code{"MCSE"} or \code{"all"}.
+#' @param posteriors A `stanreg`, `stanfit`, `brmsfit`, or `blavaan` object.
+#' @param diagnostic Diagnostic metrics to compute.  Character (vector) or list
+#'   with one or more of these options: `"ESS"`, `"Rhat"`, `"MCSE"` or `"all"`.
 #'
 #' @details
-#'   \strong{Effective Sample (ESS)} should be as large as possible, although for most applications, an effective sample size greater than 1000 is sufficient for stable estimates (Bürkner, 2017). The ESS corresponds to the number of independent samples with the same estimation power as the N autocorrelated samples. It is is a measure of \dQuote{how much independent information there is in autocorrelated chains} (\cite{Kruschke 2015, p182-3}).
+#'   **Effective Sample (ESS)** should be as large as possible, although for
+#'   most applications, an effective sample size greater than 1000 is sufficient
+#'   for stable estimates (Bürkner, 2017). The ESS corresponds to the number of
+#'   independent samples with the same estimation power as the N autocorrelated
+#'   samples. It is is a measure of \dQuote{how much independent information
+#'   there is in autocorrelated chains} (\cite{Kruschke 2015, p182-3}).
 #'   \cr \cr
-#'   \strong{Rhat} should be the closest to 1. It should not be larger than 1.1 (\cite{Gelman and Rubin, 1992}) or 1.01 (\cite{Vehtari et al., 2019}). The split Rhat statistic quantifies the consistency of an ensemble of Markov chains.
+#'   **Rhat** should be the closest to 1. It should not be larger than 1.1
+#'   (\cite{Gelman and Rubin, 1992}) or 1.01 (\cite{Vehtari et al., 2019}). The
+#'   split Rhat statistic quantifies the consistency of an ensemble of Markov
+#'   chains.
 #'   \cr \cr
-#'   \strong{Monte Carlo Standard Error (MCSE)} is another measure of accuracy of the chains. It is defined as standard deviation of the chains divided by their effective sample size (the formula for \code{mcse()} is from Kruschke 2015, p. 187). The MCSE \dQuote{provides a quantitative suggestion of how big the estimation noise is}.
+#'   **Monte Carlo Standard Error (MCSE)** is another measure of accuracy of the
+#'   chains. It is defined as standard deviation of the chains divided by their
+#'   effective sample size (the formula for `mcse()` is from Kruschke 2015, p.
+#'   187). The MCSE \dQuote{provides a quantitative suggestion of how big the
+#'   estimation noise is}.
 #'
 #'
 #' @examples
@@ -42,17 +56,10 @@ diagnostic_posterior <- function(posteriors, diagnostic = c("ESS", "Rhat"), ...)
 
 
 #' @export
-diagnostic_posterior.numeric <- function(posteriors, diagnostic = c("ESS", "Rhat"), ...) {
-  stop("`diagnostic_posterior` only works with rstanarm or brms models.")
+diagnostic_posterior.default <- function(posteriors, diagnostic = c("ESS", "Rhat"), ...) {
+  stop("'diagnostic_posterior()' only works with rstanarm, brms or blavaan models.")
 }
 
-#' @export
-diagnostic_posterior.data.frame <- diagnostic_posterior.numeric
-
-#' @export
-diagnostic_posterior.BFBayesFactor <- diagnostic_posterior.numeric
-
-
 #' @inheritParams insight::get_parameters.BFBayesFactor
 #' @inheritParams insight::get_parameters
 #' @rdname diagnostic_posterior
@@ -62,7 +69,13 @@ diagnostic_posterior.stanreg <- function(posteriors, diagnostic = "all", effects
   # Find parameters
   effects <- match.arg(effects)
   component <- match.arg(component)
-  params <- insight::find_parameters(posteriors, effects = effects, component = component, parameters = parameters, flatten = TRUE)
+  params <- insight::find_parameters(
+    posteriors,
+    effects = effects,
+    component = component,
+    parameters = parameters,
+    flatten = TRUE
+  )
 
   # If no diagnostic
   if (is.null(diagnostic)) {
@@ -102,13 +115,22 @@ diagnostic_posterior.stanreg <- function(posteriors, diagnostic = "all", effects
 
 
 #' @inheritParams insight::get_parameters
-#' @rdname diagnostic_posterior
 #' @export
-diagnostic_posterior.stanmvreg <- function(posteriors, diagnostic = "all", effects = c("fixed", "random", "all"), parameters = NULL, ...) {
+diagnostic_posterior.stanmvreg <- function(posteriors,
+                                           diagnostic = "all",
+                                           effects = c("fixed", "random", "all"),
+                                           parameters = NULL,
+                                           ...) {
+
 
   # Find parameters
   effects <- match.arg(effects)
-  all_params <- insight::find_parameters(posteriors, effects = effects, parameters = parameters, flatten = FALSE)
+  all_params <- insight::find_parameters(
+    posteriors,
+    effects = effects,
+    parameters = parameters,
+    flatten = FALSE
+  )
 
   params <- unlist(lapply(names(all_params), function(i) {
     all_params[[i]]$sigma <- NULL
@@ -160,7 +182,13 @@ diagnostic_posterior.stanmvreg <- function(posteriors, diagnostic = "all", effec
 #' @inheritParams insight::get_parameters
 #' @rdname diagnostic_posterior
 #' @export
-diagnostic_posterior.brmsfit <- function(posteriors, diagnostic = "all", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, ...) {
+diagnostic_posterior.brmsfit <- function(posteriors,
+                                         diagnostic = "all",
+                                         effects = c("fixed", "random", "all"),
+                                         component = c("conditional", "zi", "zero_inflated", "all"),
+                                         parameters = NULL,
+                                         ...) {
+
 
   # Find parameters
   effects <- match.arg(effects)
@@ -189,7 +217,7 @@ diagnostic_posterior.brmsfit <- function(posteriors, diagnostic = "all", effects
 
   # Get indices and rename
   diagnostic_df <- as.data.frame(rstan::summary(posteriors$fit)$summary)
-  diagnostic_df$Parameter <- make.names(row.names(diagnostic_df))
+  diagnostic_df$Parameter <- row.names(diagnostic_df)
   diagnostic_df$ESS <- diagnostic_df$n_eff
   # special handling for MCSE, due to some parameters (like lp__) missing in rows
   MCSE <- mcse(posteriors, effects = "all", component = "all")
