@@ -2,13 +2,13 @@
 #'
 #' This function returns the effective sample size (ESS).
 #'
-#' @param model A \code{stanreg}, \code{stanfit}, or \code{brmsfit} object.
+#' @param model A `stanreg`, `stanfit`, `brmsfit`, `blavaan`, or `MCMCglmm` object.
 #' @param ... Currently not used.
 #' @inheritParams hdi
 #'
 #' @return A data frame with two columns: Parameter name and effective sample size (ESS).
 #'
-#' @details \strong{Effective Sample (ESS)} should be as large as possible, altough for most applications, an effective sample size greater than 1,000 is sufficient for stable estimates (Bürkner, 2017). The ESS corresponds to the number of independent samples with the same estimation power as the N autocorrelated samples. It is is a measure of \dQuote{how much independent information there is in autocorrelated chains} (\emph{Kruschke 2015, p182-3}).
+#' @details **Effective Sample (ESS)** should be as large as possible, altough for most applications, an effective sample size greater than 1,000 is sufficient for stable estimates (Bürkner, 2017). The ESS corresponds to the number of independent samples with the same estimation power as the N autocorrelated samples. It is is a measure of \dQuote{how much independent information there is in autocorrelated chains} (*Kruschke 2015, p182-3*).
 #'
 #' @references \itemize{
 #'   \item Kruschke, J. (2014). Doing Bayesian data analysis: A tutorial with R, JAGS, and Stan. Academic Press.
@@ -27,6 +27,12 @@ effective_sample <- function(model, ...) {
 }
 
 
+#' @export
+effective_sample.default <- function(model, ...) {
+  stop(insight::format_message(paste0("'effective_sample()' is not yet implemented for objects of class '", class(model)[1], "'.")), call. = FALSE)
+}
+
+
 #' @rdname effective_sample
 #' @export
 effective_sample.brmsfit <- function(model, effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, ...) {
@@ -34,21 +40,20 @@ effective_sample.brmsfit <- function(model, effects = c("fixed", "random", "all"
   effects <- match.arg(effects)
   component <- match.arg(component)
 
-  pars <-
-    insight::get_parameters(
-      model,
-      effects = effects,
-      component = component,
-      parameters = parameters
-    )
+  pars <- insight::get_parameters(
+    model,
+    effects = effects,
+    component = component,
+    parameters = parameters
+  )
 
   insight::check_if_installed("rstan")
 
   s <- rstan::summary(model$fit)$summary
-  s <- subset(s, subset = make.names(rownames(s)) %in% colnames(pars))
+  s <- subset(s, subset = rownames(s) %in% colnames(pars))
 
   data.frame(
-    Parameter = make.names(rownames(s)),
+    Parameter = rownames(s),
     ESS = round(s[, "n_eff"]),
     stringsAsFactors = FALSE,
     row.names = NULL
@@ -56,7 +61,6 @@ effective_sample.brmsfit <- function(model, effects = c("fixed", "random", "all"
 }
 
 
-
 #' @rdname effective_sample
 #' @export
 effective_sample.stanreg <- function(model, effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
@@ -84,7 +88,6 @@ effective_sample.stanreg <- function(model, effects = c("fixed", "random", "all"
 }
 
 
-
 #' @export
 effective_sample.stanfit <- function(model, effects = c("fixed", "random", "all"), parameters = NULL, ...) {
   # check arguments
@@ -111,7 +114,6 @@ effective_sample.stanfit <- function(model, effects = c("fixed", "random", "all"
 }
 
 
-#' @rdname effective_sample
 #' @export
 effective_sample.blavaan <- function(model, parameters = NULL, ...) {
   insight::check_if_installed("blavaan")
@@ -127,7 +129,6 @@ effective_sample.blavaan <- function(model, parameters = NULL, ...) {
 }
 
 
-#' @rdname effective_sample
 #' @export
 effective_sample.MCMCglmm <- function(model, effects = c("fixed", "random", "all"), parameters = NULL, ...) {
   # check arguments
