@@ -1,5 +1,3 @@
-#' @importFrom insight format_table print_parameters format_value format_bf format_ci
-#' @importFrom utils modifyList
 #' @export
 format.describe_posterior <- function(x,
                                       cp,
@@ -11,9 +9,9 @@ format.describe_posterior <- function(x,
                                       ...) {
 
   # reshape CI
-  if (is.data.frame(x) && .n_unique(x$CI) > 1) {
+  if (is.data.frame(x) && insight::n_unique(x$CI) > 1) {
     att <- attributes(x)
-    x <- reshape_ci(x)
+    x <- datawizard::reshape_ci(x)
     attributes(x) <- utils::modifyList(att, attributes(x))
   }
 
@@ -86,7 +84,6 @@ format.bayesfactor_models <- function(x,
                                       caption = NULL,
                                       exact = TRUE,
                                       ...) {
-
   BFE <- x
   denominator <- attr(BFE, "denominator")
   grid.type <- attr(BFE, "BF_method")
@@ -94,13 +91,10 @@ format.bayesfactor_models <- function(x,
   formula_length <- attr(BFE, "text_length")
 
   BFE <- as.data.frame(BFE)
-  if (!log) {
-    BFE$log_BF <- exp(BFE$log_BF)
-  }
-
+  BFE$log_BF <- as.numeric(x, log = log)
   BFE$BF <- insight::format_bf(abs(BFE$log_BF), name = NULL, exact = exact, ...)
 
-  if (any((sgn <- sign(BFE$log_BF)<0)[!is.na(BFE$log_BF)])) {
+  if (any((sgn <- sign(BFE$log_BF) < 0)[!is.na(BFE$log_BF)])) {
     BFE$BF[sgn] <- paste0("-", BFE$BF[sgn])
   }
 
@@ -118,7 +112,7 @@ format.bayesfactor_models <- function(x,
   }
 
   # Denominator
-  denM <- .trim(paste0(BFE$i, " ", BFE$Model)[denominator])
+  denM <- insight::trim_ws(paste0(BFE$i, " ", BFE$Model)[denominator])
   BFE <- BFE[-denominator, ]
   BFE <- BFE[c("i", "Model", "BF")]
   colnames(BFE)[1] <- ifelse(identical(format, "html"), "Name", "")
@@ -137,7 +131,7 @@ format.bayesfactor_models <- function(x,
       caption <- c(caption, "blue")
     }
   } else {
-    footer <- .compact_list(list(
+    footer <- insight::compact_list(list(
       paste0("Against Denominator: ", denM),
       paste0("Bayes Factor Type: ", grid.type),
       if (log) "Bayes Factors are on the log-scale."
@@ -159,18 +153,15 @@ format.bayesfactor_inclusion <- function(x,
                                          caption = NULL,
                                          exact = TRUE,
                                          ...) {
-
   priorOdds <- attr(x, "priorOdds")
   matched <- attr(x, "matched")
 
   # format table
   BFE <- as.data.frame(x)
-  if (!log) {
-    BFE$log_BF <- exp(BFE$log_BF)
-  }
+  BFE$log_BF <- as.numeric(x, log = log)
   BFE$BF <- insight::format_bf(abs(BFE$log_BF), name = NULL, exact = exact, ...)
 
-  if (any((sgn <- sign(BFE$log_BF)<0)[!is.na(BFE$log_BF)])) {
+  if (any((sgn <- sign(BFE$log_BF) < 0)[!is.na(BFE$log_BF)])) {
     BFE$BF[sgn] <- paste0("-", BFE$BF[sgn])
   }
 
@@ -193,8 +184,8 @@ format.bayesfactor_inclusion <- function(x,
       caption <- c(caption, "blue")
     }
   } else {
-    footer <- .compact_list(list(
-      paste0("Compared among: ",if (matched) "matched models only" else "all models"),
+    footer <- insight::compact_list(list(
+      paste0("Compared among: ", if (matched) "matched models only" else "all models"),
       paste0("Priors odds: ", if (!is.null(priorOdds)) "custom" else "uniform-equal"),
       if (log) "Bayes Factors are on the log-scale."
     ))
@@ -215,16 +206,13 @@ format.bayesfactor_restricted <- function(x,
                                           caption = NULL,
                                           exact = TRUE,
                                           ...) {
-
   BFE <- as.data.frame(x)
 
   # Format
-  if (!log) {
-    BFE$log_BF <- exp(BFE$log_BF)
-  }
+  BFE$log_BF <- as.numeric(x, log = log)
   BFE$BF <- insight::format_bf(abs(BFE$log_BF), name = NULL, exact = exact, ...)
 
-  if (any((sgn <- sign(BFE$log_BF)<0)[!is.na(BFE$log_BF)])) {
+  if (any((sgn <- sign(BFE$log_BF) < 0)[!is.na(BFE$log_BF)])) {
     BFE$BF[sgn] <- paste0("-", BFE$BF[sgn])
   }
   BFE$log_BF <- NULL
@@ -241,7 +229,7 @@ format.bayesfactor_restricted <- function(x,
       caption <- c(caption, "blue")
     }
   } else {
-    footer <- .compact_list(list(
+    footer <- insight::compact_list(list(
       "Bayes factors for the restricted model vs. the un-restricted model.",
       if (log) "Bayes Factors are on the log-scale."
     ))
@@ -265,20 +253,18 @@ format.bayesfactor_parameters <- function(x,
   null <- attr(x, "hypothesis")
   direction <- attr(x, "direction")
 
-  if (!log) {
-    x$log_BF <- exp(x$log_BF)
-  }
+  x$log_BF <- as.numeric(x, log = log)
 
   x$BF_override <- insight::format_bf(abs(x$log_BF), name = NULL, exact = exact, ...)
 
-  if (any((sgn <- sign(x$log_BF)<0)[!is.na(x$log_BF)])) {
+  if (any((sgn <- sign(x$log_BF) < 0)[!is.na(x$log_BF)])) {
     x$BF_override[sgn] <- paste0("-", x$BF_override[sgn])
   }
   x$log_BF <- NULL
 
   # format columns and values of data frame
   out <- insight::format_table(x, digits = digits, format = format, ...)
-  colnames(out)[colnames(out)=="BF_override"] <- "BF"
+  colnames(out)[colnames(out) == "BF_override"] <- "BF"
 
   # table caption
   caption <- sprintf(
@@ -310,7 +296,7 @@ format.bayesfactor_parameters <- function(x,
       if (log) c("\n\nBayes Factors are on the log-scale.\n", "red")
     )
   } else {
-    footer <- .compact_list(list(
+    footer <- insight::compact_list(list(
       paste0("Evidence Against The Null: ", null),
       if (direction) c("Direction: "),
       if (direction < 0) "Left-Sided test",
