@@ -4,8 +4,8 @@
 #'
 #' @param x Vector of x values.
 #' @param y Vector of x values.
-#' @param method_auc Area Under the Curve (AUC) estimation method. See \code{\link{area_under_curve}}.
-#' @param method_density Density estimation method. See \code{\link{estimate_density}}.
+#' @param method_auc Area Under the Curve (AUC) estimation method. See [area_under_curve()].
+#' @param method_density Density estimation method. See [estimate_density()].
 #' @inheritParams estimate_density
 #'
 #' @examples
@@ -61,6 +61,6 @@ print.overlap <- function(x, ...) {
 plot.overlap <- function(x, ...) {
   # Can be improved through see
   data <- attributes(x)$data
-  plot(data$x, data$exclusion, type = "l")
+  graphics::plot(data$x, data$exclusion, type = "l")
   graphics::polygon(data$x, data$intersection, col = "red")
 }
