@@ -1,6 +1,6 @@
 #' Probability of being in the ROPE
 #'
-#' Compute the proportion of the whole posterior distribution that doesn't lie within a region of practical equivalence (ROPE). It is equivalent to running \code{rope(..., ci = 1)}.
+#' Compute the proportion of the whole posterior distribution that doesn't lie within a region of practical equivalence (ROPE). It is equivalent to running `rope(..., ci = 1)`.
 #'
 #' @inheritParams rope
 #'
@@ -22,8 +22,6 @@ as.double.p_rope <- function(x, ...) {
 }
 
 
-
-#' @rdname p_rope
 #' @export
 p_rope.default <- function(x, ...) {
   NULL
@@ -34,33 +32,36 @@ p_rope.default <- function(x, ...) {
 #' @export
 p_rope.numeric <- function(x, range = "default", ...) {
   out <- .p_rope(rope(x, range = range, ci = 1, ...))
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   out
 }
 
 
-#' @rdname p_rope
 #' @export
 p_rope.data.frame <- p_rope.numeric
 
-#' @rdname p_rope
+
+#' @export
+p_rope.draws <- function(x, range = "default", ...) {
+  p_rope(.posterior_draws_to_df(x), range = range, ...)
+}
+
+
 #' @export
 p_rope.emmGrid <- function(x, range = "default", ...) {
   xdf <- insight::get_parameters(x)
 
   out <- p_rope(xdf, range = range)
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   out
 }
 
 #' @export
 p_rope.emm_list <- p_rope.emmGrid
 
-#' @rdname p_rope
 #' @export
 p_rope.BFBayesFactor <- p_rope.numeric
 
-#' @rdname p_rope
 #' @export
 p_rope.MCMCglmm <- p_rope.numeric
 
@@ -70,7 +71,7 @@ p_rope.MCMCglmm <- p_rope.numeric
 p_rope.stanreg <- function(x, range = "default", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
   out <- .p_rope(rope(x, range = range, ci = 1, effects = effects, component = component, parameters = parameters, ...))
   out <- .add_clean_parameters_attribute(out, x)
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   out
 }
 
@@ -86,7 +87,7 @@ p_rope.blavaan <- p_rope.stanreg
 p_rope.brmsfit <- function(x, range = "default", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, ...) {
   out <- .p_rope(rope(x, range = range, ci = 1, effects = effects, component = component, parameters = parameters, ...))
   out <- .add_clean_parameters_attribute(out, x)
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   out
 }
 
@@ -98,7 +99,7 @@ p_rope.sim.merMod <- p_rope.stanreg
 #' @export
 p_rope.sim <- function(x, range = "default", parameters = NULL, ...) {
   out <- .p_rope(rope(x, range = range, ci = 1, parameters = parameters, ...))
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   out
 }
 
@@ -107,14 +108,14 @@ p_rope.bamlss <- function(x, range = "default", component = c("all", "conditiona
   component <- match.arg(component)
   out <- .p_rope(rope(x, range = range, ci = 1, effects = "all", component = component, parameters = parameters, ...))
   out <- .add_clean_parameters_attribute(out, x)
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   out
 }
 
 #' @export
 p_rope.mcmc <- function(x, range = "default", parameters = NULL, ...) {
   out <- .p_rope(rope(x, range = range, ci = 1, parameters = parameters, ...))
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   out
 }
 
