@@ -1,23 +1,23 @@
 #' Practical Significance (ps)
 #'
-#' Compute the probability of \strong{Practical Significance} (\strong{\emph{ps}}), which can be conceptualized as a unidirectional equivalence test. It returns the probability that effect is above a given threshold corresponding to a negligible effect in the median's direction. Mathematically, it is defined as the proportion of the posterior distribution of the median sign above the threshold.
+#' Compute the probability of **Practical Significance** (***ps***), which can be conceptualized as a unidirectional equivalence test. It returns the probability that effect is above a given threshold corresponding to a negligible effect in the median's direction. Mathematically, it is defined as the proportion of the posterior distribution of the median sign above the threshold.
 #'
 #' @inheritParams rope
-#' @param threshold The threshold value that separates significant from negligible effect. If \code{"default"}, the range is set to \code{0.1} if input is a vector, and based on \code{\link[=rope_range]{rope_range()}} if a Bayesian model is provided.
+#' @param threshold The threshold value that separates significant from negligible effect. If `"default"`, the range is set to `0.1` if input is a vector, and based on [`rope_range()`][rope_range] if a Bayesian model is provided.
 #'
 #' @return Values between 0 and 1 corresponding to the probability of practical significance (ps).
 #'
-#' @details \code{p_significance()} returns the proportion of a probability
-#'   distribution (\code{x}) that is outside a certain range (the negligible
-#'   effect, or ROPE, see argument \code{threshold}). If there are values of the
-#'   distribution both below and above the ROPE, \code{p_significance()} returns
+#' @details `p_significance()` returns the proportion of a probability
+#'   distribution (`x`) that is outside a certain range (the negligible
+#'   effect, or ROPE, see argument `threshold`). If there are values of the
+#'   distribution both below and above the ROPE, `p_significance()` returns
 #'   the higher probability of a value being outside the ROPE. Typically, this
 #'   value should be larger than 0.5 to indicate practical significance. However,
 #'   if the range of the negligible effect is rather large compared to the
-#'   range of the probability distribution \code{x}, \code{p_significance()}
+#'   range of the probability distribution `x`, `p_significance()`
 #'   will be less than 0.5, which indicates no clear practical significance.
 #'
-#' @note There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/bayestestR.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @examples
 #' library(bayestestR)
@@ -48,6 +48,10 @@ p_significance <- function(x, ...) {
 }
 
 
+#' @export
+p_significance.default <- function(x, ...) {
+  stop(insight::format_message(paste0("'p_significance()' is not yet implemented for objects of class '", class(x)[1], "'.")), call. = FALSE)
+}
 
 
 #' @rdname p_significance
@@ -73,7 +77,7 @@ p_significance.numeric <- function(x, threshold = "default", ...) {
 
 #' @export
 p_significance.data.frame <- function(x, threshold = "default", ...) {
-  obj_name <- .safe_deparse(substitute(x))
+  obj_name <- insight::safe_deparse(substitute(x))
   threshold <- .select_threshold_ps(threshold = threshold)
   x <- .select_nums(x)
 
@@ -98,6 +102,12 @@ p_significance.data.frame <- function(x, threshold = "default", ...) {
 }
 
 
+#' @export
+p_significance.draws <- function(x, threshold = "default", ...) {
+  p_significance(.posterior_draws_to_df(x), threshold = threshold, ...)
+}
+
+
 #' @export
 p_significance.parameters_simulate_model <- function(x, threshold = "default", ...) {
   obj_name <- attr(x, "object_name")
@@ -135,7 +145,7 @@ p_significance.parameters_simulate_model <- function(x, threshold = "default", .
 p_significance.MCMCglmm <- function(x, threshold = "default", ...) {
   nF <- x$Fixed$nfl
   out <- p_significance(as.data.frame(x$Sol[, 1:nF, drop = FALSE]), threshold = threshold, ...)
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   out
 }
 
@@ -143,7 +153,7 @@ p_significance.MCMCglmm <- function(x, threshold = "default", ...) {
 #' @export
 p_significance.BFBayesFactor <- function(x, threshold = "default", ...) {
   out <- p_significance(insight::get_parameters(x), threshold = threshold, ...)
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   out
 }
 
@@ -180,13 +190,12 @@ p_significance.blrm <- p_significance.bcplm
 p_significance.BGGM <- p_significance.bcplm
 
 
-#' @rdname p_significance
 #' @export
 p_significance.emmGrid <- function(x, threshold = "default", ...) {
   xdf <- insight::get_parameters(x)
 
   out <- p_significance(xdf, threshold = threshold, ...)
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   out
 }
 
@@ -195,10 +204,6 @@ p_significance.emm_list <- p_significance.emmGrid
 
 
 
-
-
-
-
 #' @rdname p_significance
 #' @export
 p_significance.stanreg <- function(x, threshold = "default", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, verbose = TRUE, ...) {
@@ -216,7 +221,7 @@ p_significance.stanreg <- function(x, threshold = "default", effects = c("fixed"
 
   attr(out, "clean_parameters") <- cleaned_parameters
   attr(out, "threshold") <- threshold
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   class(out) <- class(data)
 
   out
@@ -225,14 +230,10 @@ p_significance.stanreg <- function(x, threshold = "default", effects = c("fixed"
 #' @export
 p_significance.stanfit <- p_significance.stanreg
 
-
 #' @export
 p_significance.blavaan <- p_significance.stanreg
 
 
-
-
-
 #' @rdname p_significance
 #' @export
 p_significance.brmsfit <- function(x, threshold = "default", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, verbose = TRUE, ...) {
@@ -250,7 +251,7 @@ p_significance.brmsfit <- function(x, threshold = "default", effects = c("fixed"
 
   attr(out, "clean_parameters") <- cleaned_parameters
   attr(out, "threshold") <- threshold
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   class(out) <- class(data)
 
   out
@@ -258,7 +259,7 @@ p_significance.brmsfit <- function(x, threshold = "default", effects = c("fixed"
 
 
 
-
+# methods ---------------------------
 
 #' @rdname as.numeric.p_direction
 #' @export
@@ -277,6 +278,8 @@ as.double.p_significance <- as.numeric.p_significance
 
 
 
+# helpers --------------------------
+
 #' @keywords internal
 .select_threshold_ps <- function(model = NULL, threshold = "default") {
   # If a range is passed
