@@ -1,18 +1,18 @@
 #' Region of Practical Equivalence (ROPE)
 #'
-#' Compute the proportion of the HDI (default to the 89\% HDI) of a posterior distribution that lies within a region of practical equivalence.
+#' Compute the proportion of the HDI (default to the `89%` HDI) of a posterior distribution that lies within a region of practical equivalence.
 #'
-#' @param x Vector representing a posterior distribution. Can also be a \code{stanreg} or \code{brmsfit} model.
-#' @param range ROPE's lower and higher bounds. Should be \code{"default"} or
+#' @param x Vector representing a posterior distribution. Can also be a `stanreg` or `brmsfit` model.
+#' @param range ROPE's lower and higher bounds. Should be `"default"` or
 #' depending on the number of outcome variables a vector or a list. In models with one response,
-#' `range` should be a vector of length two (e.g., \code{c(-0.1, 0.1)}). In
+#' `range` should be a vector of length two (e.g., `c(-0.1, 0.1)`). In
 #' multivariate models, `range` should be a list with a numeric vectors for
 #' each response variable. Vector names should correspond to the name of the response
-#' variables. If \code{"default"} and input is a vector, the range is set to \code{c(-0.1,
-#' 0.1)}. If \code{"default"} and input is a Bayesian model,
-#' \code{\link[=rope_range]{rope_range()}} is used.
+#' variables. If `"default"` and input is a vector, the range is set to `c(-0.1,
+#' 0.1)`. If `"default"` and input is a Bayesian model,
+#' [`rope_range()`][rope_range] is used.
 #' @param ci The Credible Interval (CI) probability, corresponding to the proportion of HDI, to use for the percentage in ROPE.
-#' @param ci_method The type of interval to use to quantify the percentage in ROPE. Can be 'HDI' (default) or 'ETI'. See \code{\link{ci}}.
+#' @param ci_method The type of interval to use to quantify the percentage in ROPE. Can be 'HDI' (default) or 'ETI'. See [ci()].
 #'
 #' @inheritParams hdi
 #'
@@ -22,20 +22,20 @@
 #'   different from 0 does not make much sense (the probability of a single value
 #'   null hypothesis in a continuous distribution is 0). Therefore, the idea
 #'   underlining ROPE is to let the user define an area around the null value
-#'   enclosing values that are \emph{equivalent to the null} value for practical
+#'   enclosing values that are *equivalent to the null* value for practical
 #'   purposes (\cite{Kruschke 2010, 2011, 2014}).
 #'   \cr \cr
 #'   Kruschke (2018) suggests that such null value could be set, by default,
 #'   to the -0.1 to 0.1 range of a standardized parameter (negligible effect
 #'   size according to Cohen, 1988). This could be generalized: For instance,
-#'   for linear models, the ROPE could be set as \code{0 +/- .1 * sd(y)}.
+#'   for linear models, the ROPE could be set as `0 +/- .1 * sd(y)`.
 #'   This ROPE range can be automatically computed for models using the
-#'   \link{rope_range} function.
+#'   [rope_range] function.
 #'   \cr \cr
-#'   Kruschke (2010, 2011, 2014) suggests using the proportion of  the 95\%
-#'   (or 89\%, considered more stable) \link[=hdi]{HDI} that falls within the
+#'   Kruschke (2010, 2011, 2014) suggests using the proportion of  the `95%`
+#'   (or `89%`, considered more stable) [HDI][hdi] that falls within the
 #'   ROPE as an index for "null-hypothesis" testing (as understood under the
-#'   Bayesian framework, see \code{\link[=equivalence_test]{equivalence_test()}}).
+#'   Bayesian framework, see [`equivalence_test()`][equivalence_test]).
 #' }
 #' \subsection{Sensitivity to parameter's scale}{
 #'   It is important to consider the unit (i.e., the scale) of the predictors
@@ -54,22 +54,22 @@
 #'   on independence. Most problematic are parameters that only have partial
 #'   overlap with the ROPE region. In case of collinearity, the (joint) distributions
 #'   of these parameters may either get an increased or decreased ROPE, which
-#'   means that inferences based on \code{rope()} are inappropriate
+#'   means that inferences based on `rope()` are inappropriate
 #'   (\cite{Kruschke 2014, 340f}).
 #'   \cr \cr
-#'   \code{rope()} performs a simple check for pairwise correlations between
+#'   `rope()` performs a simple check for pairwise correlations between
 #'   parameters, but as there can be collinearity between more than two variables,
 #'   a first step to check the assumptions of this hypothesis testing is to look
 #'   at different pair plots. An even more sophisticated check is the projection
 #'   predictive variable selection (\cite{Piironen and Vehtari 2017}).
 #' }
 #' \subsection{Strengths and Limitations}{
-#'   \strong{Strengths:} Provides information related to the practical relevance of the effects.
+#'   **Strengths:** Provides information related to the practical relevance of the effects.
 #'   \cr \cr
-#'   \strong{Limitations:} A ROPE range needs to be arbitrarily defined. Sensitive to the scale (the unit) of the predictors. Not sensitive to highly significant effects.
+#'   **Limitations:** A ROPE range needs to be arbitrarily defined. Sensitive to the scale (the unit) of the predictors. Not sensitive to highly significant effects.
 #' }
 #'
-#' @note There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/bayestestR.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @references \itemize{
 #' \item Cohen, J. (1988). Statistical power analysis for the behavioural sciences.
@@ -125,18 +125,15 @@ as.double.rope <- function(x, ...) {
 }
 
 
-
-#' @rdname rope
 #' @export
 rope.default <- function(x, ...) {
   NULL
 }
 
 
-
 #' @rdname rope
 #' @export
-rope.numeric <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
+rope.numeric <- function(x, range = "default", ci = 0.95, ci_method = "ETI", verbose = TRUE, ...) {
   if (all(range == "default")) {
     range <- c(-0.1, 0.1)
   } else if (!all(is.numeric(range)) || length(range) != 2) {
@@ -170,12 +167,10 @@ rope.numeric <- function(x, range = "default", ci = 0.95, ci_method = "HDI", ver
 
 
 
-
-#' @rdname rope
 #' @export
-rope.data.frame <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
+rope.data.frame <- function(x, range = "default", ci = 0.95, ci_method = "ETI", verbose = TRUE, ...) {
   out <- .prepare_rope_df(x, range, ci, ci_method, verbose)
-  HDI_area_attributes <- .compact_list(out$HDI_area)
+  HDI_area_attributes <- insight::compact_list(out$HDI_area)
   dat <- data.frame(
     Parameter = rep(names(HDI_area_attributes), each = length(ci)),
     out$tmp,
@@ -184,7 +179,7 @@ rope.data.frame <- function(x, range = "default", ci = 0.95, ci_method = "HDI",
   row.names(dat) <- NULL
 
   attr(dat, "HDI_area") <- HDI_area_attributes
-  attr(dat, "object_name") <- .safe_deparse(substitute(x))
+  attr(dat, "object_name") <- insight::safe_deparse(substitute(x))
 
   class(dat) <- c("rope", "see_rope", "data.frame")
   dat
@@ -192,13 +187,19 @@ rope.data.frame <- function(x, range = "default", ci = 0.95, ci_method = "HDI",
 
 
 
-#' @rdname rope
 #' @export
-rope.emmGrid <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
+rope.draws <- function(x, range = "default", ci = 0.95, ci_method = "ETI", verbose = TRUE, ...) {
+  rope(.posterior_draws_to_df(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
+}
+
+
+
+#' @export
+rope.emmGrid <- function(x, range = "default", ci = 0.95, ci_method = "ETI", verbose = TRUE, ...) {
   xdf <- insight::get_parameters(x)
 
   dat <- rope(xdf, range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
-  attr(dat, "object_name") <- .safe_deparse(substitute(x))
+  attr(dat, "object_name") <- insight::safe_deparse(substitute(x))
   dat
 }
 
@@ -207,14 +208,13 @@ rope.emm_list <- rope.emmGrid
 
 
 
-#' @rdname rope
 #' @export
-rope.BFBayesFactor <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
+rope.BFBayesFactor <- function(x, range = "default", ci = 0.95, ci_method = "ETI", verbose = TRUE, ...) {
   if (all(range == "default")) {
     range <- rope_range(x, verbose = verbose)
   }
   out <- rope(insight::get_parameters(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   out
 }
 
@@ -223,32 +223,29 @@ rope.BFBayesFactor <- function(x, range = "default", ci = 0.95, ci_method = "HDI
 rope.bamlss <- rope.BFBayesFactor
 
 
-#' @rdname rope
 #' @export
-rope.MCMCglmm <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
+rope.MCMCglmm <- function(x, range = "default", ci = 0.95, ci_method = "ETI", verbose = TRUE, ...) {
   nF <- x$Fixed$nfl
   out <- rope(as.data.frame(x$Sol[, 1:nF, drop = FALSE]), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   out
 }
 
 
 #' @export
-rope.mcmc <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
+rope.mcmc <- function(x, range = "default", ci = 0.95, ci_method = "ETI", verbose = TRUE, ...) {
   out <- rope(as.data.frame(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(out, "object_name") <- NULL
-  attr(out, "data") <- .safe_deparse(substitute(x))
+  attr(out, "data") <- insight::safe_deparse(substitute(x))
   out
 }
 
 
-
-
 #' @export
-rope.bcplm <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
+rope.bcplm <- function(x, range = "default", ci = 0.95, ci_method = "ETI", verbose = TRUE, ...) {
   out <- rope(insight::get_parameters(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(out, "object_name") <- NULL
-  attr(out, "data") <- .safe_deparse(substitute(x))
+  attr(out, "data") <- insight::safe_deparse(substitute(x))
   out
 }
 
@@ -267,7 +264,7 @@ rope.mcmc.list <- rope.bcplm
 
 
 #' @keywords internal
-.rope <- function(x, range = c(-0.1, 0.1), ci = 0.95, ci_method = "HDI", verbose = TRUE) {
+.rope <- function(x, range = c(-0.1, 0.1), ci = 0.95, ci_method = "ETI", verbose = TRUE) {
   ci_bounds <- ci(x, ci = ci, method = ci_method, verbose = verbose)
 
   if (anyNA(ci_bounds)) {
@@ -296,7 +293,7 @@ rope.mcmc.list <- rope.bcplm
 
 #' @rdname rope
 #' @export
-rope.stanreg <- function(x, range = "default", ci = 0.95, ci_method = "HDI", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, verbose = TRUE, ...) {
+rope.stanreg <- function(x, range = "default", ci = 0.95, ci_method = "ETI", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, verbose = TRUE, ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
 
@@ -321,7 +318,7 @@ rope.stanreg <- function(x, range = "default", ci = 0.95, ci_method = "HDI", eff
   out <- .prepare_output(rope_data, insight::clean_parameters(x), inherits(x, "stanmvreg"))
 
   attr(out, "HDI_area") <- attr(rope_data, "HDI_area")
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   class(out) <- class(rope_data)
 
   out
@@ -339,7 +336,7 @@ rope.blavaan <- rope.stanreg
 rope.brmsfit <- function(x,
                          range = "default",
                          ci = 0.95,
-                         ci_method = "HDI",
+                         ci_method = "ETI",
                          effects = c("fixed", "random", "all"),
                          component = c("conditional", "zi", "zero_inflated", "all"),
                          parameters = NULL,
@@ -353,10 +350,14 @@ rope.brmsfit <- function(x,
     range <- rope_range(x, verbose = verbose)
     # we expect a list with named vectors (length two) in the multivariate case.
     # Names state the response variable.
-  } else if (insight::is_multivariate(x) &&
-    (!is.list(range) || length(range) != length(insight::find_response(x)) ||
-      names(range) != insight::find_response(x))) {
-    stop("With a multivariate model, `range` should be 'default' or a list of named numeric vectors with length 2.")
+  } else if (insight::is_multivariate(x)) {
+    if (
+      !is.list(range) ||
+        length(range) < length(insight::find_response(x)) ||
+        !all(names(range) %in% insight::find_response(x))
+    ) {
+      stop("With a multivariate model, `range` should be 'default' or a list of named numeric vectors with length 2.")
+    }
   } else if (!all(is.numeric(range)) || length(range) != 2) {
     stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
   }
@@ -407,7 +408,7 @@ rope.brmsfit <- function(x,
   }
 
   attr(out, "HDI_area") <- attr(rope_data, "HDI_area")
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   class(out) <- class(rope_data)
 
   out
@@ -416,7 +417,7 @@ rope.brmsfit <- function(x,
 
 
 #' @export
-rope.sim.merMod <- function(x, range = "default", ci = 0.95, ci_method = "HDI", effects = c("fixed", "random", "all"), parameters = NULL, verbose = TRUE, ...) {
+rope.sim.merMod <- function(x, range = "default", ci = 0.95, ci_method = "ETI", effects = c("fixed", "random", "all"), parameters = NULL, verbose = TRUE, ...) {
   effects <- match.arg(effects)
 
   if (all(range == "default")) {
@@ -432,7 +433,7 @@ rope.sim.merMod <- function(x, range = "default", ci = 0.95, ci_method = "HDI",
     tmp <- getropedata$tmp
     HDI_area <- getropedata$HDI_area
 
-    if (!.is_empty_object(tmp)) {
+    if (!insight::is_empty_object(tmp)) {
       tmp <- .clean_up_tmp_stanreg(
         tmp,
         group = .x,
@@ -440,7 +441,7 @@ rope.sim.merMod <- function(x, range = "default", ci = 0.95, ci_method = "HDI",
         parms = names(parms)
       )
 
-      if (!.is_empty_object(HDI_area)) {
+      if (!insight::is_empty_object(HDI_area)) {
         attr(tmp, "HDI_area") <- HDI_area
       }
     } else {
@@ -450,7 +451,7 @@ rope.sim.merMod <- function(x, range = "default", ci = 0.95, ci_method = "HDI",
     tmp
   })
 
-  dat <- do.call(rbind, args = c(.compact_list(list), make.row.names = FALSE))
+  dat <- do.call(rbind, args = c(insight::compact_list(list), make.row.names = FALSE))
 
   dat <- switch(effects,
     fixed = .select_rows(dat, "Group", "fixed"),
@@ -459,10 +460,10 @@ rope.sim.merMod <- function(x, range = "default", ci = 0.95, ci_method = "HDI",
   )
 
   if (all(dat$Group == dat$Group[1])) {
-    dat <- .remove_column(dat, "Group")
+    dat <- datawizard::data_remove(dat, "Group", verbose = FALSE)
   }
 
-  HDI_area_attributes <- lapply(.compact_list(list), attr, "HDI_area")
+  HDI_area_attributes <- lapply(insight::compact_list(list), attr, "HDI_area")
 
   if (effects != "all") {
     HDI_area_attributes <- HDI_area_attributes[[1]]
@@ -471,7 +472,7 @@ rope.sim.merMod <- function(x, range = "default", ci = 0.95, ci_method = "HDI",
   }
 
   attr(dat, "HDI_area") <- HDI_area_attributes
-  attr(dat, "object_name") <- .safe_deparse(substitute(x))
+  attr(dat, "object_name") <- insight::safe_deparse(substitute(x))
 
   dat
 }
@@ -479,7 +480,7 @@ rope.sim.merMod <- function(x, range = "default", ci = 0.95, ci_method = "HDI",
 
 
 #' @export
-rope.sim <- function(x, range = "default", ci = 0.95, ci_method = "HDI", parameters = NULL, verbose = TRUE, ...) {
+rope.sim <- function(x, range = "default", ci = 0.95, ci_method = "ETI", parameters = NULL, verbose = TRUE, ...) {
   if (all(range == "default")) {
     range <- rope_range(x, verbose = verbose)
   } else if (!all(is.numeric(range)) || length(range) != 2) {
@@ -492,7 +493,7 @@ rope.sim <- function(x, range = "default", ci = 0.95, ci_method = "HDI", paramet
   dat <- getropedata$tmp
   HDI_area <- getropedata$HDI_area
 
-  if (!.is_empty_object(dat)) {
+  if (!insight::is_empty_object(dat)) {
     dat <- .clean_up_tmp_stanreg(
       dat,
       group = "fixed",
@@ -500,14 +501,14 @@ rope.sim <- function(x, range = "default", ci = 0.95, ci_method = "HDI", paramet
       parms = names(parms)
     )
 
-    if (!.is_empty_object(HDI_area)) {
+    if (!insight::is_empty_object(HDI_area)) {
       attr(dat, "HDI_area") <- HDI_area
     }
   } else {
     dat <- NULL
   }
 
-  attr(dat, "object_name") <- .safe_deparse(substitute(x))
+  attr(dat, "object_name") <- insight::safe_deparse(substitute(x))
 
   dat
 }
