@@ -137,7 +137,7 @@ si.stanreg <- function(posterior, prior = NULL,
   out <- .prepare_output(temp, cleaned_parameters, inherits(posterior, "stanmvreg"))
 
   attr(out, "ci_method") <- "SI"
-  attr(out, "object_name") <- .safe_deparse(substitute(posterior))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(posterior))
   class(out) <- class(temp)
   attr(out, "plot_data") <- attr(temp, "plot_data")
 
@@ -169,7 +169,7 @@ si.emmGrid <- function(posterior, prior = NULL,
   )
 
   attr(out, "ci_method") <- "SI"
-  attr(out, "object_name") <- .safe_deparse(substitute(posterior))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(posterior))
   out
 }
 
@@ -177,20 +177,26 @@ si.emmGrid <- function(posterior, prior = NULL,
 si.emm_list <- si.emmGrid
 
 
+#' @export
+si.stanfit <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, effects = c("fixed", "random", "all"), ...) {
+  out <- si(insight::get_parameters(posterior, effects = effects),
+    prior = prior, BF = BF, verbose = verbose
+  )
+  attr(out, "object_name") <- insight::safe_deparse(substitute(posterior))
+  out
+}
+
+#' @export
+si.get_predicted <- function(posterior, ...) {
+  out <- si(as.data.frame(t(posterior)), ...)
+  attr(out, "object_name") <- insight::safe_deparse(substitute(posterior))
+  out
+}
+
+
 #' @rdname si
 #' @export
 si.data.frame <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
-  if (length(BF) > 1) {
-    SIs <- lapply(BF, function(i) {
-      si(posterior, prior = prior, BF = i, verbose = verbose, ...)
-    })
-    out <- do.call(rbind, SIs)
-
-    attr(out, "plot_data") <- attr(SIs[[1]], "plot_data")
-    class(out) <- unique(c("bayestestR_si", "bayestestR_ci", class(out)))
-    return(out)
-  }
-
   if (is.null(prior)) {
     prior <- posterior
     warning(insight::format_message(
@@ -200,6 +206,38 @@ si.data.frame <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...)
     ), call. = FALSE)
   }
 
+  if (verbose && (nrow(posterior) < 4e4 || nrow(prior) < 4e4)) {
+    warning(
+      "Support intervals might not be precise.\n",
+      "For precise support intervals, sampling at least 40,000 posterior samples is recommended.",
+      call. = FALSE
+    )
+  }
+
+  out <- lapply(BF, function(BFi) {
+    .si.data.frame(posterior, prior, BFi)
+  })
+  out <- do.call(rbind, out)
+
+  attr(out, "ci_method") <- "SI"
+  attr(out, "ci") <- BF
+  attr(out, "plot_data") <- .make_BF_plot_data(posterior, prior, 0, 0, ...)$plot_data
+  class(out) <- unique(c("bayestestR_si", "see_si", "bayestestR_ci", "see_ci", class(out)))
+
+  out
+}
+
+
+#' @export
+si.draws <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
+  si(.posterior_draws_to_df(posterior), prior = prior, BF = BF, verbose = verbose, ...)
+}
+
+
+
+# Helper ------------------------------------------------------------------
+
+.si.data.frame <- function(posterior, prior, BF, ...) {
   sis <- matrix(NA, nrow = ncol(posterior), ncol = 2)
   for (par in seq_along(posterior)) {
     sis[par, ] <- .si(posterior[[par]],
@@ -215,30 +253,9 @@ si.data.frame <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...)
     CI_high = sis[, 2],
     stringsAsFactors = FALSE
   )
-
-  attr(out, "ci_method") <- "SI"
-  attr(out, "plot_data") <- .make_BF_plot_data(posterior, prior, 0, 0, ...)$plot_data
-  class(out) <- unique(c("bayestestR_si", "see_si", "bayestestR_ci", "see_ci", class(out)))
-
-  out
 }
 
 
-#' @export
-si.stanfit <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, effects = c("fixed", "random", "all"), ...) {
-  si(insight::get_parameters(posterior, effects = effects))
-}
-
-#' @export
-si.get_predicted <- function(posterior, ...) {
-  out <- si(as.data.frame(t(posterior)), ...)
-  attr(out, "object_name") <- .safe_deparse(substitute(posterior))
-  out
-}
-
-# Helper ------------------------------------------------------------------
-
-
 
 #' @keywords internal
 .si <- function(posterior, prior, BF = 1, extend_scale = 0.05, precision = 2^8, ...) {
