@@ -8,7 +8,6 @@
 }
 
 #' @keywords internal
-#' @importFrom insight get_parameters
 .clean_priors_and_posteriors.stanreg <- function(posterior, prior,
                                                  verbose = TRUE,
                                                  effects, component, ...) {
@@ -19,7 +18,7 @@
 
 
   prior <- try(unupdate(prior, verbose = verbose), silent = TRUE)
-  if (is(prior, "try-error")) {
+  if (methods::is(prior, "try-error")) {
     if (grepl("flat priors", prior)) {
       prior <- paste0(
         prior, "Could not therefore compute Bayes factors, as these inform about ",
@@ -45,7 +44,6 @@
 
 
 #' @keywords internal
-#' @importFrom insight get_parameters
 .clean_priors_and_posteriors.blavaan <- function(posterior, prior,
                                                  verbose = TRUE, ...) {
   # Get Priors
@@ -66,12 +64,10 @@
 
 
 #' @keywords internal
-#' @importFrom stats update
-.clean_priors_and_posteriors.emmGrid <- function(posterior, prior,
+.clean_priors_and_posteriors.emmGrid <- function(posterior,
+                                                 prior,
                                                  verbose = TRUE) {
-  if (!requireNamespace("emmeans")) {
-    stop("Package 'emmeans' required for this function to work. Please install it by running `install.packages('emmeans')`.")
-  }
+  insight::check_if_installed("emmeans")
 
   if (is.null(prior)) {
     prior <- posterior
@@ -79,9 +75,30 @@
       "Prior not specified! ",
       "Please provide the original model to get meaningful results."
     )
-  } else if (!inherits(prior, "emmGrid")) { # then is it a model
+  }
+
+
+  if (!inherits(prior, "emmGrid")) { # then is it a model
+    on.exit(
+      stop(
+        "Unable to reconstruct prior estimates.\n",
+        "Perhaps the emmGrid object has been transformed or regrid()-ed?\n",
+        "See function details.\n\n",
+        "Instead, you can reestimate the emmGrid with a prior model, Try:\n",
+        "\tprior_model <- unupdate(mode)\n",
+        "\tprior_emmgrid <- emmeans(prior_model, ...) # pass this as the 'prior' argument.",
+        call. = FALSE
+      )
+    )
+
+    if (inherits(prior, "brmsfit")) {
+      stop("Cannot rebuild prior emmGrid from a brmsfit model.", call. = FALSE)
+    }
+
+
     prior <- try(unupdate(prior, verbose = verbose), silent = TRUE)
-    if (is(prior, "try-error")) {
+    if (inherits(prior, "try-error")) {
+      on.exit() # undo general error message
       if (grepl("flat priors", prior)) {
         prior <- paste0(
           prior, "Could not therefore compute Bayes factors, as these inform about ",
@@ -92,17 +109,17 @@
       }
       stop(prior, call. = FALSE)
     }
+
     prior <- emmeans::ref_grid(prior)
     prior <- prior@post.beta
 
     if (!isTRUE(all.equal(colnames(prior), colnames(posterior@post.beta)))) {
-      stop(
-        "Unable to reconstruct prior estimates.\n",
-        "Perhaps the emmGrid object has been transformed? See function details.\n",
+      stop("post.beta and prior.beta are non-conformable arguments.",
         call. = FALSE
       )
     }
     prior <- stats::update(posterior, post.beta = prior)
+    on.exit() # undo general error message
   }
 
   prior <- insight::get_parameters(prior)
@@ -122,9 +139,16 @@
       "Prior not specified! ",
       "Please provide the original model to get meaningful results."
     )
-  } else if (!inherits(prior, "emm_list")) {
+  }
+
+  if (!inherits(prior, "emm_list")) { # prior is a model
+
+    if (inherits(prior, "brmsfit")) {
+      stop("Cannot rebuild prior emm_list from a brmsfit model.", call. = FALSE)
+    }
+
     prior <- try(unupdate(prior, verbose = verbose), silent = TRUE)
-    if (is(prior, "try-error")) {
+    if (inherits(prior, "try-error")) {
       if (grepl("flat priors", prior)) {
         prior <- paste0(
           prior, "Could not therefore compute Bayes factors, as these inform about ",
@@ -163,7 +187,6 @@
 # BMA ---------------------------------------------------------------------
 
 #' @keywords internal
-#' @importFrom stats as.formula terms terms.formula
 .get_model_table <- function(BFGrid, priorOdds = NULL, add_effects_table = TRUE, ...) {
   denominator <- attr(BFGrid, "denominator")
   BFGrid <- rbind(BFGrid[denominator, ], BFGrid[-denominator, ])
@@ -171,7 +194,7 @@
 
   # This looks like it does nothing, but this is needed to prevent Inf in large BFs.
   # Small BFs are better than large BFs
-  BFGrid <- update(BFGrid, reference = "top")
+  BFGrid <- stats::update(BFGrid, reference = "top")
 
   # Prior and post odds
   Modelnames <- BFGrid$Model
@@ -259,17 +282,18 @@
 
 # make_BF_plot_data -------------------------------------------------------
 
-#' @importFrom stats median mad approx
-#' @importFrom utils stack
 #' @keywords internal
-.make_BF_plot_data <- function(posterior, prior, direction, null,
-                               extend_scale = 0.05, precision = 2^8, ...) {
-  if (!requireNamespace("logspline")) {
-    stop("Package \"logspline\" needed for this function to work. Please install it.")
-  }
+.make_BF_plot_data <- function(posterior,
+                               prior,
+                               direction,
+                               null,
+                               extend_scale = 0.05,
+                               precision = 2^8,
+                               ...) {
+  insight::check_if_installed("logspline")
 
   estimate_samples_density <- function(samples) {
-    nm <- .safe_deparse(substitute(samples))
+    nm <- insight::safe_deparse(substitute(samples))
     samples <- utils::stack(samples)
     samples <- split(samples, samples$ind)
 
@@ -349,12 +373,10 @@
 # As numeric vector -------------------------------------------------------
 
 #' @export
-as.numeric.bayesfactor_inclusion <- function(x, ...) {
-  if ("data.frame" %in% class(x)) {
-    return(as.numeric(as.vector(x$BF)))
-  } else {
-    return(as.vector(x))
-  }
+as.numeric.bayesfactor_inclusion <- function(x, log = FALSE, ...) {
+  out <- x[["log_BF"]]
+  if (!log) out <- exp(out)
+  return(out)
 }
 
 #' @export
@@ -366,6 +388,8 @@ as.numeric.bayesfactor_parameters <- as.numeric.bayesfactor_inclusion
 #' @export
 as.numeric.bayesfactor_restricted <- as.numeric.bayesfactor_inclusion
 
+## Double:
+
 #' @export
 as.double.bayesfactor_inclusion <- as.numeric.bayesfactor_inclusion
 
@@ -384,9 +408,7 @@ as.double.bayesfactor_restricted <- as.numeric.bayesfactor_inclusion
 
 #' @keywords internal
 .logspline <- function(x, ...) {
-  if (!requireNamespace("logspline")) {
-    stop("Package \"logspline\" needed for this function to work. Please install it.")
-  }
+  insight::check_if_installed("logspline")
 
   # arg_names <- names(formals(logspline::logspline, envir = parent.frame()))
   arg_names <- names(formals(logspline::logspline)) # support R<3.6.0
