@@ -1,3 +1,13 @@
+#' @keywords internal
+.check_ci_fun <- function(dots) {
+  ci_fun <- "hdi"
+  if (identical(dots$ci_method, "spi")) {
+    ci_fun <- "spi"
+  }
+  ci_fun
+}
+
+
 #' @keywords internal
 .check_ci_argument <- function(x, ci, verbose = TRUE) {
   if (ci > 1) {
@@ -5,7 +15,7 @@
       warning("`ci` should be less than 1, returning NAs.")
     }
     return(data.frame(
-      "CI" = ci * 100,
+      "CI" = ci,
       "CI_low" = NA,
       "CI_high" = NA
     ))
@@ -13,29 +23,19 @@
 
   if (ci == 1) {
     return(data.frame(
-      "CI" = ci * 100,
+      "CI" = ci,
       "CI_low" = min(x, na.rm = TRUE),
       "CI_high" = max(x, na.rm = TRUE)
     ))
   }
 
-  if (anyNA(x)) {
-    if (verbose) {
-      warning("The posterior contains NAs, returning NAs.")
-    }
-    return(data.frame(
-      "CI" = ci * 100,
-      "CI_low" = NA,
-      "CI_high" = NA
-    ))
-  }
 
   if (length(x) < 3) {
     if (verbose) {
       warning("The posterior is too short, returning NAs.")
     }
     return(data.frame(
-      "CI" = ci * 100,
+      "CI" = ci,
       "CI_low" = NA,
       "CI_high" = NA
     ))
@@ -50,7 +50,7 @@
 .compute_interval_dataframe <- function(x, ci, verbose, fun) {
   numeric_variables <- sapply(x, is.numeric, simplify = TRUE)
 
-  out <- .compact_list(lapply(
+  out <- insight::compact_list(lapply(
     x[, numeric_variables, drop = FALSE],
     get(fun, asNamespace("bayestestR")),
     ci = ci,
@@ -64,7 +64,13 @@
     row.names = NULL
   )
 
-  class(dat) <- unique(c(paste0("bayestestR_", fun), paste0("see_", fun), class(dat)))
+  # rename for SPI, should be HDI
+  if (identical(fun, "spi")) {
+    class(dat) <- unique(c("bayestestR_hdi", "see_hdi", "bayestestR_spi", class(dat)))
+  } else {
+    class(dat) <- unique(c(paste0("bayestestR_", fun), paste0("see_", fun), class(dat)))
+  }
+
   dat
 }
 
@@ -90,10 +96,10 @@
   d <- do.call(rbind, list(fixed, random))
 
   if (length(unique(d$Group)) == 1) {
-    d <- .remove_column(d, "Group")
+    d <- datawizard::data_remove(d, "Group", verbose = FALSE)
   }
 
-  list(result = d, data = do.call(cbind, .compact_list(list(fixed.data, random.data))))
+  list(result = d, data = do.call(cbind, insight::compact_list(list(fixed.data, random.data))))
 }
 
 
