@@ -24,20 +24,20 @@ if (require("testthat") && requireNamespace("rstanarm", quietly = TRUE)) {
     })
 
     # brms ----------------------
-    # m <- insight::download_model("brms_zi_3")
-    #
-    # test_that("map_estimate", {
-    #   expect_equal(
-    #     map_estimate(m, effects = "all", component = "all")$Parameter,
-    #     c(
-    #       "b_Intercept", "b_child", "b_camper", "r_persons[1,Intercept]",
-    #       "r_persons[2,Intercept]", "r_persons[3,Intercept]", "r_persons[4,Intercept]",
-    #       "sd_persons__Intercept", "b_zi_Intercept", "b_zi_child", "b_zi_camper",
-    #       "r_persons__zi[1,Intercept]", "r_persons__zi[2,Intercept]", "r_persons__zi[3,Intercept]",
-    #       "r_persons__zi[4,Intercept]", "sd_persons__zi_Intercept"
-    #     )
-    #   )
-    # })
+    m <- insight::download_model("brms_zi_3")
+
+    test_that("map_estimate", {
+      expect_equal(
+        map_estimate(m, effects = "all", component = "all")$Parameter,
+        c(
+          "b_Intercept", "b_child", "b_camper", "r_persons[1,Intercept]",
+          "r_persons[2,Intercept]", "r_persons[3,Intercept]", "r_persons[4,Intercept]",
+          "sd_persons__Intercept", "b_zi_Intercept", "b_zi_child", "b_zi_camper",
+          "r_persons__zi[1,Intercept]", "r_persons__zi[2,Intercept]", "r_persons__zi[3,Intercept]",
+          "r_persons__zi[4,Intercept]", "sd_persons__zi_Intercept"
+        )
+      )
+    })
 
     # BayesFactor -------------
     m <- correlationBF(y = iris$Sepal.Length, x = iris$Sepal.Width)
