@@ -1,4 +1,4 @@
-if (suppressPackageStartupMessages(require("bayestestR", quietly = TRUE)) && require("testthat", quietly = TRUE) && require("rstanarm", quietly = TRUE) && require("brms", quietly = TRUE)) {
+if (requiet("bayestestR") && requiet("testthat") && requiet("rstanarm") && requiet("brms")) {
   test_that("rope", {
     expect_equal(as.numeric(rope(distribution_normal(1000, 0, 1), verbose = FALSE)), 0.084, tolerance = 0.01)
     expect_equal(equivalence_test(distribution_normal(1000, 0, 1))$ROPE_Equivalence, "Undecided")
@@ -19,7 +19,7 @@ if (suppressPackageStartupMessages(require("bayestestR", quietly = TRUE)) && req
     expect_equal(rope(rnorm(1000, mean = 0, sd = 3), ci = c(.1, .5, .9), verbose = FALSE)$CI, c(.1, .5, .9))
 
     x <- equivalence_test(distribution_normal(1000, 1, 1), ci = c(.50, .99))
-    expect_equal(x$ROPE_Percentage[2], 0.0494, tolerance = 0.01)
+    expect_equal(x$ROPE_Percentage[2], 0.0484, tolerance = 0.01)
     expect_equal(x$ROPE_Equivalence[2], "Undecided")
 
     expect_error(rope(distribution_normal(1000, 0, 1), range = c(0.0, 0.1, 0.2)))
@@ -37,7 +37,7 @@ if (suppressPackageStartupMessages(require("bayestestR", quietly = TRUE)) && req
 
   .runThisTest <- Sys.getenv("RunAllbayestestRTests") == "yes"
   if (.runThisTest) {
-    if (require("insight")) {
+    if (requiet("insight")) {
       m <- insight::download_model("stanreg_merMod_5")
       p <- insight::get_parameters(m, effects = "all")
 
@@ -65,31 +65,31 @@ if (suppressPackageStartupMessages(require("bayestestR", quietly = TRUE)) && req
 }
 
 .runThisTest <- Sys.getenv("RunAllbayestestRTests") == "yes"
-if (.runThisTest && require("brms", quietly = TRUE)) {
-  set.seed(123)
-  model <- brm(mpg ~ wt + gear, data = mtcars, iter = 500)
-  rope <- rope(model, verbose = FALSE)
-
-  test_that("rope (brms)", {
-    expect_equal(rope$ROPE_high, -rope$ROPE_low, tolerance = 0.01)
-    expect_equal(rope$ROPE_high[1], 0.6026948)
-    expect_equal(rope$ROPE_Percentage, c(0.00, 0.00, 0.50), tolerance = 0.1)
-  })
-
-  model <- brm(mvbind(mpg, disp) ~ wt + gear, data = mtcars, iter = 500)
-  rope <- rope(model, verbose = FALSE)
-
-  test_that("rope (brms, multivariate)", {
-    expect_equal(rope$ROPE_high, -rope$ROPE_low, tolerance = 0.01)
-    expect_equal(rope$ROPE_high[1], 0.6026948, tolerance = 0.01)
-    expect_equal(rope$ROPE_high[4], 12.3938694, tolerance = 0.01)
-    expect_equal(
-      rope$ROPE_Percentage,
-      c(0, 0, 0.493457, 0.072897, 0, 0.508411),
-      tolerance = 0.1
-    )
-  })
-}
+# if (.runThisTest && require("brms", quietly = TRUE)) {
+#   set.seed(123)
+#   model <- brm(mpg ~ wt + gear, data = mtcars, iter = 500)
+#   rope <- rope(model, verbose = FALSE)
+#
+#   test_that("rope (brms)", {
+#     expect_equal(rope$ROPE_high, -rope$ROPE_low, tolerance = 0.01)
+#     expect_equal(rope$ROPE_high[1], 0.6026948)
+#     expect_equal(rope$ROPE_Percentage, c(0.00, 0.00, 0.50), tolerance = 0.1)
+#   })
+#
+#   model <- brm(mvbind(mpg, disp) ~ wt + gear, data = mtcars, iter = 500)
+#   rope <- rope(model, verbose = FALSE)
+#
+#   test_that("rope (brms, multivariate)", {
+#     expect_equal(rope$ROPE_high, -rope$ROPE_low, tolerance = 0.01)
+#     expect_equal(rope$ROPE_high[1], 0.6026948, tolerance = 0.01)
+#     expect_equal(rope$ROPE_high[4], 12.3938694, tolerance = 0.01)
+#     expect_equal(
+#       rope$ROPE_Percentage,
+#       c(0, 0, 0.493457, 0.072897, 0, 0.508411),
+#       tolerance = 0.1
+#     )
+#   })
+# }
 
 if (require("BayesFactor", quietly = TRUE)) {
   mods <- regressionBF(mpg ~ am + cyl, mtcars, progress = FALSE)
